CamelRatiosIndex-package: CamelRatiosIndex: Multivariate-Weighted Indexing of CAMEL...

CamelRatiosIndex-packageR Documentation

CamelRatiosIndex: Multivariate-Weighted Indexing of CAMEL Ratios for Bank Performance

Description

logo

Computes a composite year-on-year index for bank performance assessment using the CAMEL framework (Capital Adequacy, Asset Quality, Management Efficiency, Earnings, Liquidity). The multivariate weighting scheme employs factor analysis with robust covariance estimation to derive communality-based weights from the correlation matrix of CAMEL ratios. Provides functions for index computation, visualization, and comparison across banks and time periods.The methodology is described in Ayimah et al. (2023a) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.9734/bpi/mono/978-81-19315-32-1")} and Ayimah et al. (2023b) https://ajtem.com/index.php/ajtem/article/view/53.

Author(s)

Maintainer: John Coker Ayimah jayimah@htu.edu.gh [copyright holder]

Authors:

See Also

Useful links:


CamelRatiosIndex documentation built on June 20, 2026, 5:07 p.m.